Decompositions
==============

The available decompositions in Piquasso.

Clements decomposition
----------------------

.. automodule:: piquasso.decompositions.clements
   :members:

References:
    - W. R. Clements, P. C. Humphreys, B. J. Metcalf, W. S. Kolthammer, I. A. Walmsley,
      "An Optimal Design for Universal Multiport Interferometers",
      Optica 3, 1460-1465 (2016),
      `arXiv:1603.08788 <https://arxiv.org/abs/1603.08788>`_.
